Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3365)

Unified Diff: device/bluetooth/bluetooth_remote_gatt_characteristic_mac.h

Issue 2634873002: Bluetooth: macOS: Implement BluetoothRemoteGattCharacteristicMac::UnsubscribeFromNotifications (Closed)
Patch Set: Adding last_notify_value for macOS Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: device/bluetooth/bluetooth_remote_gatt_characteristic_mac.h
diff --git a/device/bluetooth/bluetooth_remote_gatt_characteristic_mac.h b/device/bluetooth/bluetooth_remote_gatt_characteristic_mac.h
index 01aed06eddba3f0670040deaa96594afdbab4f58..b0f8d69353e0758fbec668c4a94860dc2955712f 100644
--- a/device/bluetooth/bluetooth_remote_gatt_characteristic_mac.h
+++ b/device/bluetooth/bluetooth_remote_gatt_characteristic_mac.h
@@ -122,10 +122,13 @@ class DEVICE_BLUETOOTH_EXPORT BluetoothRemoteGattCharacteristicMac
std::pair<ValueCallback, ErrorCallback> read_characteristic_value_callbacks_;
// WriteRemoteCharacteristic request callbacks.
std::pair<base::Closure, ErrorCallback> write_characteristic_value_callbacks_;
// Stores SubscribeToNotifications request callbacks.
typedef std::pair<base::Closure, ErrorCallback> PendingNotifyCallbacks;
// Stores SubscribeToNotifications request callbacks.
PendingNotifyCallbacks subscribe_to_notification_callbacks_;
+ // Stores UnsubscribeFromNotifications request callbacks.
+ PendingNotifyCallbacks unsubscribe_from_notification_callbacks_;
// Map of descriptors, keyed by descriptor identifier.
std::unordered_map<std::string,
std::unique_ptr<BluetoothRemoteGattDescriptorMac>>
@@ -122,10 +122,13 @@ class DEVICE_BLUETOOTH_EXPORT BluetoothRemoteGattCharacteristicMac
// WriteRemoteCharacteristic request callbacks.
std::pair<base::Closure, ErrorCallback> write_characteristic_value_callbacks_;
- // Stores SubscribeToNotifications request callbacks.
+ // Stores callbacks for SubscribeToNotifications and
+ // UnsubscribeFromNotifications requests.
typedef std::pair<base::Closure, ErrorCallback> PendingNotifyCallbacks;
// Stores SubscribeToNotifications request callbacks.
« no previous file with comments | « device/bluetooth/bluetooth_remote_gatt_characteristic.cc ('k') | device/bluetooth/bluetooth_remote_gatt_characteristic_mac.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698